@@ -1,4 +1,4 @@
-INSERT INTO version (table_name, table_version) values ('dialog','3');
+INSERT INTO version (table_name, table_version) values ('dialog','5');
 CREATE TABLE dialog (
     id INT(10) UNSIGNED AUTO_INCREMENT PRIMARY KEY NOT NULL,
     hash_entry INT(10) UNSIGNED NOT NULL,
@@ -18,10 +18,23 @@ CREATE TABLE dialog (
     callee_sock VARCHAR(64) NOT NULL,
     state INT(10) UNSIGNED NOT NULL,
     start_time INT(10) UNSIGNED NOT NULL,
-    timeout INT(10) UNSIGNED NOT NULL,
-    sflags INT(10) UNSIGNED NOT NULL,
-    toroute INT(10) UNSIGNED NOT NULL
+    timeout INT(10) UNSIGNED DEFAULT 0 NOT NULL,
+    sflags INT(10) UNSIGNED DEFAULT 0 NOT NULL,
+    toroute INT(10) UNSIGNED DEFAULT 0 NOT NULL,
+    toroute_name VARCHAR(32),
+    req_uri VARCHAR(128) NOT NULL
 ) ENGINE=MyISAM;
 
 CREATE INDEX hash_idx ON dialog (hash_entry, hash_id);
 
+INSERT INTO version (table_name, table_version) values ('dialog_vars','1');
+CREATE TABLE dialog_vars (
+    id INT(10) UNSIGNED AUTO_INCREMENT PRIMARY KEY NOT NULL,
+    hash_entry INT(10) UNSIGNED NOT NULL,
+    hash_id INT(10) UNSIGNED NOT NULL,
+    dialog_key VARCHAR(128) NOT NULL,
+    dialog_value VARCHAR(512) NOT NULL
+) ENGINE=MyISAM;
+
+CREATE INDEX hash_idx ON dialog_vars (hash_entry, hash_id);
+
